@@ -23,4 +23,9 @@ def duplicate_current_frame(layer : LayerInput, napari_viewer : Viewer, axis : i
     else:
         result = Image(new_image, name=new_name)
 
-    return result
\ No newline at end of file
+    return result
+
+def isimage(value):
+    return isinstance(value, np.ndarray) or str(type(value)) in ["<class 'cupy._core.core.ndarray'>",
+                                                          "<class 'dask.array.core.Array'>",
+                                                          "<class 'pyclesperanto_prototype._tier0._pycl.OCLArray'>"]
